# Good Egg Validation Report

Generated: 2026-02-09T19:47:47.109504

Total authors scored: **43**

## Score Distribution
- Mean: 0.5942
- Std Dev: 0.3669
- CV: 0.6175
- Range: [0.0000, 0.9519]

## Trust Level Distribution
| Level | Count | Percentage |
|-------|-------|------------|
| HIGH | 26 | 60.5% |
| LOW | 3 | 7.0% |
| MEDIUM | 6 | 14.0% |
| UNKNOWN | 8 | 18.6% |

## Correlations with Score
| Factor | Pearson r |
|--------|-----------|
| Account Age | 0.408 |
| Merged Prs | 0.5137 |
| Unique Repos | 0.6591 |

## Language Match Impact
- With language match (n=35): mean = 0.7300
- Without language match (n=8): mean = 0.0000
- Difference: +0.7300

## Per-Repository Breakdown
| Repository | Count | Mean | Min | Max |
|-----------|-------|------|-----|-----|
| astral-sh/ruff | 3 | 0.7905 | 0.6476 | 0.8780 |
| block/goose | 3 | 0.3970 | 0.0000 | 0.7121 |
| huggingface/transformers | 6 | 0.6397 | 0.0000 | 0.9136 |
| kubernetes/kubernetes | 4 | 0.7857 | 0.4789 | 0.9449 |
| langchain-ai/langchain | 10 | 0.3863 | 0.0000 | 0.9135 |
| pytorch/pytorch | 7 | 0.6240 | 0.0000 | 0.9519 |
| vercel/next.js | 6 | 0.7181 | 0.0000 | 0.9100 |
| vllm-project/vllm | 4 | 0.6167 | 0.0000 | 0.8845 |

## Surprising Low Scores
Users with >10 merged PRs but LOW trust:
| Login | Context Repo | Merged PRs |
|-------|-------------|------------|
| nimeshakya | vercel/next.js | 70 |

## Methodology Quality Indicators
- Score spread: GOOD (CV > 0.3, scores are well-differentiated)
- Level balance: GOOD (both HIGH and LOW scores present)

## Individual Results
| Login | Repo | Score | Level | PRs | Repos | Age (d) | Lang Match |
|-------|------|-------|-------|-----|-------|---------|------------|
| albanD | pytorch/pytorch | 0.9519 | HIGH | 130 | 52 | 4414 | Yes |
| rata | kubernetes/kubernetes | 0.9449 | HIGH | 272 | 50 | 6153 | Yes |
| thecaptain789 | huggingface/transformers | 0.9136 | HIGH | 26 | 22 | 12 | Yes |
| mdrxy | langchain-ai/langchain | 0.9135 | HIGH | 500 | 22 | 2178 | Yes |
| timneutkens | vercel/next.js | 0.9100 | HIGH | 500 | 21 | 4418 | Yes |
| chuanqi129 | pytorch/pytorch | 0.9002 | HIGH | 144 | 19 | 3844 | Yes |
| pavan-sh | vercel/next.js | 0.8920 | HIGH | 31 | 17 | 4433 | Yes |
| Etelis | vllm-project/vllm | 0.8845 | HIGH | 70 | 17 | 1583 | Yes |
| desertfire | pytorch/pytorch | 0.8830 | HIGH | 187 | 16 | 4736 | Yes |
| mtshiba | astral-sh/ruff | 0.8780 | HIGH | 225 | 16 | 2641 | Yes |
| anijain2305 | pytorch/pytorch | 0.8707 | HIGH | 315 | 16 | 3830 | Yes |
| ccurme | langchain-ai/langchain | 0.8655 | HIGH | 500 | 13 | 3248 | Yes |
| koba1t | kubernetes/kubernetes | 0.8640 | HIGH | 127 | 15 | 3195 | Yes |
| keenborder786 | langchain-ai/langchain | 0.8585 | HIGH | 120 | 15 | 2637 | Yes |
| youwalther65 | kubernetes/kubernetes | 0.8552 | HIGH | 25 | 12 | 3163 | Yes |
| tohtana | huggingface/transformers | 0.8482 | HIGH | 160 | 12 | 1783 | Yes |
| feedthejim | vercel/next.js | 0.8459 | HIGH | 199 | 13 | 4009 | Yes |
| 11happy | astral-sh/ruff | 0.8458 | HIGH | 59 | 11 | 1870 | Yes |
| dllehr-amd | vllm-project/vllm | 0.8419 | HIGH | 54 | 13 | 1595 | Yes |
| Deep-unlearning | huggingface/transformers | 0.8347 | HIGH | 34 | 10 | 2257 | Yes |
| mischnic | vercel/next.js | 0.8345 | HIGH | 500 | 10 | 4636 | Yes |
| devjiwonchoi | vercel/next.js | 0.8265 | HIGH | 500 | 12 | 1160 | Yes |
| eustlb | huggingface/transformers | 0.7628 | HIGH | 57 | 6 | 1540 | Yes |
| CuiYifeng | pytorch/pytorch | 0.7624 | HIGH | 49 | 6 | 2407 | Yes |
| crawdaddie | vllm-project/vllm | 0.7404 | HIGH | 24 | 8 | 4127 | Yes |
| sw-square | block/goose | 0.7121 | HIGH | 26 | 6 | 1664 | Yes |
| Alex-ley-scrub | astral-sh/ruff | 0.6476 | MEDIUM | 8 | 3 | 1552 | Yes |
| jasiecky | langchain-ai/langchain | 0.6470 | MEDIUM | 8 | 3 | 1840 | Yes |
| TomAlon | langchain-ai/langchain | 0.5783 | MEDIUM | 8 | 2 | 3753 | Yes |
| OiPunk | huggingface/transformers | 0.4789 | MEDIUM | 1 | 1 | 2163 | Yes |
| varshadeshmane92 | kubernetes/kubernetes | 0.4789 | MEDIUM | 1 | 1 | 234 | Yes |
| dorien-koelemeijer | block/goose | 0.4789 | MEDIUM | 13 | 1 | 2142 | Yes |
| Nitin75408 | langchain-ai/langchain | 0.0000 | UNKNOWN | 0 | 0 | 1167 | No |
| Leeaoyin | langchain-ai/langchain | 0.0000 | UNKNOWN | 0 | 0 | 2458 | No |
| justin55afdfdsf5ds45f4ds5f45ds4 | langchain-ai/langchain | 0.0000 | UNKNOWN | 0 | 0 | 617 | No |
| VintLin | langchain-ai/langchain | 0.0000 | LOW | 4 | 2 | 3266 | Yes |
| MohammedYaseenAhmedKhan | langchain-ai/langchain | 0.0000 | UNKNOWN | 0 | 0 | 118 | No |
| ddelgadovargas-cyber | pytorch/pytorch | 0.0000 | UNKNOWN | 0 | 0 | 59 | No |
| gderossi | pytorch/pytorch | 0.0000 | LOW | 2 | 1 | 4148 | Yes |
| VishnuVV27 | vllm-project/vllm | 0.0000 | UNKNOWN | 0 | 0 | 1804 | No |
| daniel7an | huggingface/transformers | 0.0000 | UNKNOWN | 0 | 0 | 1765 | No |
| nimeshakya | vercel/next.js | 0.0000 | LOW | 70 | 8 | 1907 | Yes |
| zanesq | block/goose | 0.0000 | UNKNOWN | 0 | 0 | 1889 | No |
